# Domain Concepts

Key domain concepts, terminology, and mental models for this project.

## Glossary

<!-- Define domain-specific terms used in the codebase. -->

| Term | Definition |
|---|---|
| | |

## Mental Models

<!-- Describe the key abstractions and mental models that inform the design. -->

## Invariants

<!-- List important business rules or invariants that must always hold true. -->
